The Zone class — GramophoneTools 0.7.0-beta documentation

# The Zone class

class `Zone.` `Zone`(begin, end, zone_type='generic')

  Correlates with beginning and end of Frames to add functionality.

  Parameters

    - begin (int) – The beginning of the Zone in pixels.

    - end (int) – The end of the Zone in pixels.

    - zone_type (str) – The type of the Zone for Rules. ‘generic’ by default.

  `check`(pos)

    Returns True if the given position is in the zone.

    Parameters

      pos (int) – The position in pixels.

    Return type

      bool